@@ -204,11 +204,15 @@ void umm_poison_free(void *ptr) {
  */
 
 bool umm_poison_check(void) {
+    UMM_CRITICAL_DECL(id_poison);
+
     bool ok = true;
     unsigned short int cur;
 
     UMM_CHECK_INITIALIZED();
 
+    UMM_CRITICAL_ENTRY(id_poison);
+
     /* Now iterate through the blocks list */
     cur = UMM_NBLOCK(0) & UMM_BLOCKNO_MASK;
 
@@ -223,6 +227,7 @@ bool umm_poison_check(void) {
 
         cur = UMM_NBLOCK(cur) & UMM_BLOCKNO_MASK;
     }
+    UMM_CRITICAL_EXIT(id_poison);
 
     return ok;
 }
